@@ -224,7 +224,7 @@ static long t1dec_cnt = 0;
 
 
 static int
-dec_sigpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
+dec_sigpass(jpc_dec_t *dec, jpc_mqdec_t *mqdec, int bitpos,
             int orient,
             int vcausalflag, jas_matrix_t *flags, jas_matrix_t *data)
 {
@@ -414,7 +414,7 @@ dec_rawsigpass(jpc_dec_t *dec, jpc_bitstream_t *in, int bitpos,
 
 
 static int
-dec_refpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
+dec_refpass(jpc_dec_t *dec, jpc_mqdec_t *mqdec, int bitpos,
             int vcausalflag, jas_matrix_t *flags, jas_matrix_t *data)
 {
     int i;
@@ -619,7 +619,7 @@ plabel \
 }
 
 static int
-dec_clnpass(jpc_dec_t *dec, register jpc_mqdec_t *mqdec, int bitpos,
+dec_clnpass(jpc_dec_t *dec, jpc_mqdec_t *mqdec, int bitpos,
             int orient, int vcausalflag, int segsymflag, jas_matrix_t *flags,
             jas_matrix_t *data)
 {
