@@ -172,8 +172,7 @@ void init_idctref (void);
 extern boolean pureDCT;
 
 void
-mpeg_jrevdct(data)
-    DCTBLOCK data;
+mpeg_jrevdct(DCTBLOCK data)
 {
   if (pureDCT) reference_rev_dct(data);
   else mpeg_jrevdct_quick(data);
@@ -186,14 +185,13 @@ mpeg_jrevdct(data)
  */
 
 void
-mpeg_jrevdct_quick(data)
-    DCTBLOCK data;
+mpeg_jrevdct_quick(DCTBLOCK data)
 {
   int32 tmp0, tmp1, tmp2, tmp3;
   int32 tmp10, tmp11, tmp12, tmp13;
   int32 z1, z2, z3, z4, z5;
   int32 d0, d1, d2, d3, d4, d5, d6, d7;
-  register DCTELEM *dataptr;
+  DCTELEM *dataptr;
   int rowctr;
   SHIFT_TEMPS
 
@@ -213,7 +211,7 @@ mpeg_jrevdct_quick(data)
      * row DCT calculations can be simplified this way.
      */
 
-    register int *idataptr = (int*)dataptr;
+    int *idataptr = (int*)dataptr;
     d0 = dataptr[0];
     d1 = dataptr[1];
     if ((d1 == 0) && (idataptr[1] | idataptr[2] | idataptr[3]) == 0) {
@@ -221,7 +219,7 @@ mpeg_jrevdct_quick(data)
       if (d0) {
           /* Compute a 32 bit value to assign. */
           DCTELEM dcval = (DCTELEM) (d0 << PASS1_BITS);
-          register int v = (dcval & 0xffff) | ((dcval << 16) & 0xffff0000);
+          int v = (dcval & 0xffff) | ((dcval << 16) & 0xffff0000);
 
           idataptr[0] = v;
           idataptr[1] = v;
@@ -1223,7 +1221,8 @@ static double itrans_coef[8][8];
 
 
 
-void init_idctref() {
+void 
+init_idctref (void) {
 /*----------------------------------------------------------------------------
    initialize DCT coefficient matrix
 -----------------------------------------------------------------------------*/
@@ -1243,8 +1242,7 @@ void init_idctref() {
 
 /* perform IDCT matrix multiply for 8x8 coefficient block */
 
-void reference_rev_dct(block)
-int16 *block;
+void reference_rev_dct(int16 *block)
 {
   int i, j, k, v;
   double partial_product;
