@@ -35,7 +35,7 @@ ppm_hashpixel(pixel const p) {
 
 colorhist_vector
 ppm_computecolorhist( pixel ** const pixels,
-                      const int cols, const int rows, const int maxcolors,
+                      const int cols, const int rows, const int maxColorCt,
                       int * const colorsP ) {
 /*----------------------------------------------------------------------------
    Compute a color histogram for the image described by 'pixels',
@@ -43,21 +43,21 @@ ppm_computecolorhist( pixel ** const pixels,
    for each color in the image and for each one the number of pixels
    of that color (i.e. a color histogram).
 
-   If 'maxcolors' is zero, make the output have 5 spare slots at the end
+   If 'maxColorCt' is zero, make the output have 5 spare slots at the end
    for expansion.
 
-   If 'maxcolors' is nonzero, make the output have 'maxcolors' slots in
+   If 'maxColorCt' is nonzero, make the output have 'maxColorCt' slots in
    it, and if there are more colors than that in the image, don't return
    anything except a NULL pointer.
 -----------------------------------------------------------------------------*/
     colorhash_table cht;
     colorhist_vector chv;
 
-    cht = ppm_computecolorhash(pixels, cols, rows, maxcolors, colorsP);
+    cht = ppm_computecolorhash(pixels, cols, rows, maxColorCt, colorsP);
     if (cht == NULL)
         chv = NULL;
     else {
-        chv = ppm_colorhashtocolorhist(cht, maxcolors);
+        chv = ppm_colorhashtocolorhist(cht, maxColorCt);
         ppm_freecolorhash(cht);
     }
     return chv;
@@ -94,7 +94,7 @@ ppm_computecolorhist2(FILE * const ifP,
 
 void
 ppm_addtocolorhist( colorhist_vector chv,
-                    int * const colorsP, const int maxcolors,
+                    int * const colorsP, const int maxColorCt,
                     const pixel * const colorP,
                     const int value, const int position ) {
     int i, j;
@@ -114,7 +114,7 @@ ppm_addtocolorhist( colorhist_vector chv,
             chv[position].value = value;
             return;
         }
-    if ( *colorsP < maxcolors ) {
+    if ( *colorsP < maxColorCt ) {
         /* Didn't find it, but there's room to add it; so do so. */
         for ( i = *colorsP; i > position; --i )
             chv[i] = chv[i - 1];
@@ -189,10 +189,10 @@ buildHashTable(FILE *          const ifP,
                unsigned int    const rows,
                pixval          const maxval,
                int             const format,
-               unsigned int    const maxcolors,
+               unsigned int    const maxColorCt,
                colorhash_table const cht,
                pixel *         const rowbuffer,
-               int *           const nColorsP,
+               int *           const colorCtP,
                bool *          const tooManyColorsP,
                const char **   const errorP) {
 /*----------------------------------------------------------------------------
@@ -201,14 +201,14 @@ buildHashTable(FILE *          const ifP,
 
   Even if we fail, we may add some colors to 'cht'.
 
-  As soon as we've seen more that 'maxcolors' colors, we quit.  In that
+  As soon as we've seen more that 'maxColorCt' colors, we quit.  In that
   case, only, we return *tooManyColorsP == true.  That is not a failure.
-  'maxcolors' == 0 means infinity.
+  'maxColorCt' == 0 means infinity.
 -----------------------------------------------------------------------------*/
     unsigned int row;
-    unsigned int nColors;
+    unsigned int colorCt;
 
-    nColors = 0;   /* initial value */
+    colorCt = 0;   /* initial value */
     *tooManyColorsP = FALSE; /* initial value */
     *errorP = NULL;  /* initial value */
 
@@ -236,8 +236,8 @@ buildHashTable(FILE *          const ifP,
                 ++chl->ch.value;
             else {
                 /* It's not in the hash yet, so add it (if allowed) */
-                ++nColors;
-                if (maxcolors > 0 && nColors > maxcolors)
+                ++colorCt;
+                if (maxColorCt > 0 && colorCt > maxColorCt)
                     *tooManyColorsP = TRUE;
                 else {
                     MALLOCVAR(chl);
@@ -252,7 +252,7 @@ buildHashTable(FILE *          const ifP,
             }
         }
     }
-    *nColorsP = nColors;
+    *colorCtP = colorCt;
 }
 
 
@@ -261,8 +261,8 @@ static void
 computecolorhash(pixel **          const pixels,
                  unsigned int      const cols,
                  unsigned int      const rows,
-                 unsigned int      const maxcolors,
-                 int *             const nColorsP,
+                 unsigned int      const maxColorCt,
+                 int *             const colorCtP,
                  FILE *            const ifP,
                  pixval            const maxval,
                  int               const format,
@@ -285,8 +285,8 @@ computecolorhash(pixel **          const pixels,
 
    Return the number of colors found as *colorsP.
 
-   However, if 'maxcolors' is nonzero and the number of colors is
-   greater than 'maxcolors', return a null return value and *colorsP
+   However, if 'maxColorCt' is nonzero and the number of colors is
+   greater than 'maxColorCt', return a null return value and *colorsP
    undefined.
 -----------------------------------------------------------------------------*/
     pixel * rowbuffer;  /* malloc'ed */
@@ -307,9 +307,9 @@ computecolorhash(pixel **          const pixels,
         if (cht == NULL)
             pm_asprintf(errorP, "Unable to allocate color hash.");
         else {
-            buildHashTable(ifP, pixels, cols, rows, maxval, format, maxcolors,
+            buildHashTable(ifP, pixels, cols, rows, maxval, format, maxColorCt,
                            cht, rowbuffer,
-                           nColorsP, &tooManyColors, errorP);
+                           colorCtP, &tooManyColors, errorP);
 
             if (tooManyColors) {
                 ppm_freecolorhash(cht);
@@ -330,13 +330,13 @@ colorhash_table
 ppm_computecolorhash(pixel ** const pixels,
                      int      const cols,
                      int      const rows,
-                     int      const maxcolors,
+                     int      const maxColorCt,
                      int *    const colorsP) {
 
     colorhash_table cht;
     const char * error;
 
-    computecolorhash(pixels, cols, rows, maxcolors, colorsP,
+    computecolorhash(pixels, cols, rows, maxColorCt, colorsP,
                      NULL, 0, 0, &cht, &error);
 
     if (error) {
@@ -355,13 +355,13 @@ ppm_computecolorhash2(FILE * const ifP,
                       int    const rows,
                       pixval const maxval,
                       int    const format,
-                      int    const maxcolors,
+                      int    const maxColorCt,
                       int *  const colorsP ) {
 
     colorhash_table cht;
     const char * error;
 
-    computecolorhash(NULL, cols, rows, maxcolors, colorsP,
+    computecolorhash(NULL, cols, rows, maxColorCt, colorsP,
                      ifP, maxval, format, &cht, &error);
 
     if (error) {
@@ -433,40 +433,40 @@ colorHashSize(colorhash_table const cht) {
 /*----------------------------------------------------------------------------
    Return the number of colors in the colorhash table 'cht'
 -----------------------------------------------------------------------------*/
-    unsigned int nColors;
+    unsigned int colorCt;
         /* Number of colors found so far */
     int i;
     /* Loop through the hash table. */
-    nColors = 0;
+    colorCt = 0;
     for (i = 0; i < HASH_SIZE; ++i) {
         colorhist_list chl;
         for (chl = cht[i]; chl; chl = chl->next)
-            ++nColors;
+            ++colorCt;
     }
-    return nColors;
+    return colorCt;
 }
 
 
 
 colorhist_vector
-ppm_colorhashtocolorhist(colorhash_table const cht, int const maxcolors) {
+ppm_colorhashtocolorhist(colorhash_table const cht, int const maxColorCt) {
 
     colorhist_vector chv;
     colorhist_list   chl;
     unsigned int     chvSize;
 
-    if (maxcolors == 0)
+    if (maxColorCt == 0)
         /* We leave space for 5 more colors so caller can add in special
            colors like background color and transparent color.
         */
         chvSize = colorHashSize(cht) + 5;
     else
         /* Caller is responsible for making sure there are no more
-           than 'maxcolors' colors in the colorhash table.  NOTE:
-           Before March 2002, the maxcolors == 0 invocation didn't
+           than 'maxColorCt' colors in the colorhash table.  NOTE:
+           Before March 2002, the maxColorCt == 0 invocation didn't
            exist.
         */
-        chvSize = maxcolors;
+        chvSize = maxColorCt;
 
     /* Collate the hash table into a simple colorhist array. */
     MALLOCARRAY(chv, chvSize);
@@ -600,15 +600,14 @@ ppm_freecolorhash(colorhash_table const cht) {
 */
 
 colorhash_table
-ppm_colorrowtocolorhash(colorrow, ncolors)
-    pixel *colorrow;
-    int ncolors;
-{
+ppm_colorrowtocolorhash(pixel * const colorrow,
+                        int     const colorCt) {
+
     colorhash_table cht;
     int i;
 
     cht = ppm_alloccolorhash();
-    for( i = 0; i < ncolors; i++ ) {
+    for( i = 0; i < colorCt; i++ ) {
         if( ppm_lookupcolor(cht, &colorrow[i]) < 0 ) {
             if( ppm_addtocolorhash(cht, &colorrow[i], i) < 0 )
                 pm_error("out of memory adding to hash table");
@@ -618,72 +617,83 @@ ppm_colorrowtocolorhash(colorrow, ncolors)
 }
 
 
-pixel *
-ppm_computecolorrow(pixels, cols, rows, maxcolors, ncolorsP)
-    pixel **pixels;
-    int cols, rows, maxcolors;
-    int *ncolorsP;
-{
-    int ncolors, row, col;
-    colorhash_table cht;
-    pixel *pixrow;
 
-    pixrow = ppm_allocrow(maxcolors);
-    cht = ppm_alloccolorhash(); ncolors = 0;
-    for( row = 0; row < rows; row++ ) {
-        for( col = 0; col < cols; col++ ) {
-            if( ppm_lookupcolor(cht, &pixels[row][col]) < 0 ) {
-                if( ncolors >= maxcolors ) {
+pixel *
+ppm_computecolorrow(pixel ** const pixels,
+                    int      const cols,
+                    int      const rows,
+                    int      const maxColorCt,
+                    int *    const colorCtP) {
+
+    int colorCt;
+    colorhash_table cht;
+    pixel * pixrow;
+    unsigned int row;
+
+    pixrow = ppm_allocrow(maxColorCt);
+    cht = ppm_alloccolorhash(); colorCt = 0;
+    for (row = 0; row < rows; ++row) {
+        unsigned int col;
+        for (col = 0; col < cols; ++col) {
+            int rc;
+            rc = ppm_lookupcolor(cht, &pixels[row][col]);
+            if (rc < 0 ) {
+                if (colorCt >= maxColorCt) {
                     ppm_freerow(pixrow);
-                    pixrow = (pixel *)0;
-                    ncolors = -1;
+                    pixrow = NULL;
+                    colorCt = -1;
                     goto fail;
                 }
-                if( ppm_addtocolorhash(cht, &pixels[row][col], ncolors) < 0 )
+                if (ppm_addtocolorhash(cht, &pixels[row][col], colorCt) < 0)
                     pm_error("out of memory adding to hash table");
-                pixrow[ncolors] = pixels[row][col];
-                ++ncolors;
+                pixrow[colorCt] = pixels[row][col];
+                ++colorCt;
             }
         }
     }
 fail:
     ppm_freecolorhash(cht);
 
-    *ncolorsP = ncolors;
+    *colorCtP = colorCt;
     return pixrow;
 }
 
 
+
 pixel *
-ppm_mapfiletocolorrow(file, maxcolors, ncolorsP, maxvalP)
-    FILE *file;
-    int maxcolors;
-    int *ncolorsP;
-    pixval *maxvalP;
-{
-    int cols, rows, format, row, col, ncolors;
+ppm_mapfiletocolorrow(FILE *   const fileP,
+                      int      const maxColorCt,
+                      int *    const colorCtP,
+                      pixval * const maxvalP) {
+
+    int cols, rows, format, colorCt;
     pixel *pixrow, *temprow;
     colorhash_table cht;
+    unsigned int row;
 
-    pixrow = ppm_allocrow(maxcolors);
+    pixrow = ppm_allocrow(maxColorCt);
 
-    ppm_readppminit(file, &cols, &rows, maxvalP, &format);
+    ppm_readppminit(fileP, &cols, &rows, maxvalP, &format);
     temprow = ppm_allocrow(cols);
-    cht = ppm_alloccolorhash(); ncolors = 0;
-    for( row = 0; row < rows; row++ ) {
-        ppm_readppmrow(file, temprow, cols, *maxvalP, format);
-        for( col = 0; col < cols; col++ ) {
-            if( ppm_lookupcolor(cht, &temprow[col]) < 0 ) {
-                if( ncolors >= maxcolors ) {
+    cht = ppm_alloccolorhash(); colorCt = 0;
+    for (row = 0; row < rows; ++row) {
+        unsigned int col;
+        ppm_readppmrow(fileP, temprow, cols, *maxvalP, format);
+        for (col = 0; col < cols; ++col) {
+            int rc;
+            rc = ppm_lookupcolor(cht, &temprow[col]);
+            if (rc < 0) {
+                if (colorCt >= maxColorCt) {
                     ppm_freerow(pixrow);
-                    pixrow = (pixel *)0;
-                    ncolors = -1;
+                    pixrow = NULL;
+                    colorCt = -1;
                     goto fail;
                 }
-                if( ppm_addtocolorhash(cht, &temprow[col], ncolors) < 0 )
+                rc = ppm_addtocolorhash(cht, &temprow[col], colorCt);
+                if (rc < 0)
                     pm_error("out of memory adding to hash table");
-                pixrow[ncolors] = temprow[col];
-                ++ncolors;
+                pixrow[colorCt] = temprow[col];
+                ++colorCt;
             }
         }
     }
@@ -691,7 +701,7 @@ fail:
     ppm_freecolorhash(cht);
     ppm_freerow(temprow);
 
-    *ncolorsP = ncolors;
+    *colorCtP = colorCt;
     return pixrow;
 }
 
@@ -738,60 +748,59 @@ pixelCmp(const void * const a,
 
 void
 ppm_sortcolorrow(pixel * const colorrow,
-                 int     const ncolors,
+                 int     const colorCt,
                  int (*cmpfunc)(pixel *, pixel *)) {
 
     if (cmpfunc) {
         customCmp = cmpfunc;
-        qsort((void *)colorrow, ncolors, sizeof(pixel), customStub);
+        qsort((void *)colorrow, colorCt, sizeof(pixel), customStub);
     } else
-        qsort((void *)colorrow, ncolors, sizeof(pixel), pixelCmp);
+        qsort((void *)colorrow, colorCt, sizeof(pixel), pixelCmp);
 }
 
 
 
 int
-ppm_addtocolorrow(colorrow, ncolorsP, maxcolors, pixelP)
-    pixel *colorrow;
-    int *ncolorsP;
-    int maxcolors;
-    pixel *pixelP;
-{
-    int i;
-    pixval r, g, b;
+ppm_addtocolorrow(pixel * const colorrow,
+                  int *   const colorCtP,
+                  int     const maxColorCt,
+                  pixel * const pixelP) {
 
-    r = PPM_GETR(*pixelP);
-    g = PPM_GETG(*pixelP);
-    b = PPM_GETB(*pixelP);
+    pixval const r = PPM_GETR(*pixelP);
+    pixval const g = PPM_GETG(*pixelP);
+    pixval const b = PPM_GETB(*pixelP);
 
-    for( i = 0; i < *ncolorsP; i++ ) {
-        if( PPM_GETR(colorrow[i]) == r &&
+    unsigned int i;
+
+    for (i = 0; i < *colorCtP; ++i) {
+        if (PPM_GETR(colorrow[i]) == r &&
             PPM_GETG(colorrow[i]) == g &&
-            PPM_GETB(colorrow[i]) == b )
+            PPM_GETB(colorrow[i]) == b)
                 return i;
     }
 
-    i = *ncolorsP;
-    if( i >= maxcolors )
+    i = *colorCtP;
+    if (i >= maxColorCt)
         return -1;
     colorrow[i] = *pixelP;
-    ++*ncolorsP;
+    ++*colorCtP;
     return i;
 }
 
 
+
 int
 ppm_findclosestcolor(const pixel * const colormap,
-                     int           const ncolors,
+                     int           const colorCt,
                      const pixel * const pP) {
 /*----------------------------------------------------------------------------
-  The index in colormap[] (which has 'ncolors' entries) of the color that is
+  The index in colormap[] (which has 'colorCt' entries) of the color that is
   closest to color *pP.
 
   Where two entries in colormap[] are identical, return the lesser of their
   two indices.
 
-  Iff there are no colors in the amp ('ncolors' is zero), return -1.
+  Iff there are no colors in the amp ('colorCt' is zero), return -1.
 -----------------------------------------------------------------------------*/
     unsigned int i;
     int ind;
@@ -800,7 +809,7 @@ ppm_findclosestcolor(const pixel * const colormap,
     bestDist = UINT_MAX;
     ind = -1;
 
-    for (i = 0; i < ncolors && bestDist > 0; ++i) {
+    for (i = 0; i < colorCt && bestDist > 0; ++i) {
         unsigned int const dist = PPM_DISTANCE(*pP, colormap[i]);
 
         if (dist < bestDist ) {
@@ -814,14 +823,17 @@ ppm_findclosestcolor(const pixel * const colormap,
 
 
 void
-ppm_colorrowtomapfile(FILE *ofp, pixel *colormap, int ncolors, pixval maxval)
-{
-    int i;
+ppm_colorrowtomapfile(FILE *  const ofP,
+                      pixel * const colormap,
+                      int     const colorCt,
+                      pixval  const maxval) {
 
-    ppm_writeppminit(ofp, ncolors, 1, maxval, 1);
-    for( i = 0; i < ncolors; i++ )
-        ppm_writeppmrow(ofp, &colormap[i], 1, maxval, 1);
+    unsigned int i;
+
+    ppm_writeppminit(ofP, colorCt, 1, maxval, 1);
+
+    for (i = 0; i < colorCt; ++i)
+        ppm_writeppmrow(ofP, &colormap[i], 1, maxval, 1);
 }
 
 
-
